/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 34945
 |         NATIONAL MENTAL HEALTH SERVICES SURVEY (N-MHSS), 2010
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\34945-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE stfips    1='(01) ALABAMA' 2='(02) ALASKA' 4='(04) ARIZONA'
                  5='(05) ARKANSAS' 6='(06) CALIFORNIA' 8='(08) COLORADO'
                  9='(09) CONNECTICUT' 10='(10) DELAWARE'
                  11='(11) DIST OF COLUMBIA' 12='(12) FLORIDA'
                  13='(13) GEORGIA' 15='(15) HAWAII' 16='(16) IDAHO'
                  17='(17) ILLINOIS' 18='(18) INDIANA' 19='(19) IOWA'
                  20='(20) KANSAS' 21='(21) KENTUCKY' 22='(22) LOUISIANA'
                  23='(23) MAINE' 24='(24) MARYLAND' 25='(25) MASSACHUSETTS'
                  26='(26) MICHIGAN' 27='(27) MINNESOTA'
                  28='(28) MISSISSIPPI' 29='(29) MISSOURI' 30='(30) MONTANA'
                  31='(31) NEBRASKA' 32='(32) NEVADA' 33='(33) NEW HAMPSHIRE'
                  34='(34) NEW JERSEY' 35='(35) NEW MEXICO'
                  36='(36) NEW YORK' 37='(37) NORTH CAROLINA'
                  38='(38) NORTH DAKOTA' 39='(39) OHIO' 40='(40) OKLAHOMA'
                  41='(41) OREGON' 42='(42) PENNSYLVANIA'
                  44='(44) RHODE ISLAND' 45='(45) SOUTH CAROLINA'
                  46='(46) SOUTH DAKOTA' 47='(47) TENNESSEE' 48='(48) TEXAS'
                  49='(49) UTAH' 50='(50) VERMONT' 51='(51) VIRGINIA'
                  53='(53) WASHINGTON' 54='(54) WEST VIRGINIA'
                  55='(55) WISCONSIN' 56='(56) WYOMING'
                  88='(88) US TERRITORIES' ;
  VALUE mode      1='(1) Phone - Full' 2='(2) Phone - Short' 3='(3) Mail'
                  4='(4) Web' ;
  VALUE mhintake  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhdiagef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhreferf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE saserv    -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mentalhf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  1='(1) Yes' ;
  VALUE adminsef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE settingf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE settin0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE settin1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE facilitf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  1='(1) Psychiatric Hospital'
                  2='(2) Separate inpatient psychiatric unit of a general hospital'
                  3='(3) Residential treatment center for children'
                  4='(4) Residential treatment center for adults'
                  5='(5) Outpatient, day treatment or partial hospitalization mental health facility'
                  6='(6) Multi-setting (non-hospital) mental health facility' ;
  VALUE focus     -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  1='(1) Mental health services'
                  3='(3) Mix of mental health and substance abuse' ;
  VALUE ownershf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  1='(1) Private for-profit organization'
                  2='(2) Private non-profit organization'
                  3='(3) State mental health agency (SMHA)'
                  5='(5) Other State government'
                  6='(6) Regional or district authority'
                  7='(7) Local, county, or municipal government'
                  8='(8) U.S Department of Veterans Affairs' 9='(9) Other' ;
  VALUE religiof  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE treatacf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE treatbef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE treatcof  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE treatfaf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE treatelf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE treatgrf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE treatpsf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE treatduf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE treatp0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE treattef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE treatoth  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE assertcf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhcasemf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhchronf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhconsuf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mheducaf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fampsycf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhhousif  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE illnessf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhlegal   -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhemgcy   -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhpsychf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE smokingf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhsuicif  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE suppempf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE supphouf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fostercf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhvocref  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhoth     -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE childadf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE adults    -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE seniors   -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE sed       -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE transitf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE spmi      -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE alzhdemf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhandsa   -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE mhandotf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE posttraf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE veterns   -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE traumatf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE glbt      -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE forensic  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE progoth   -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE hearimpf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE langengf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE langspaf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE langoth   -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE crisistf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  1='(1) Yes, only within this facility'
                  2='(2) Yes, only offsite'
                  3='(3) Yes, both within this facility and offsite'
                  4='(4) No, we do not have a crisis intervention team' ;
  VALUE compresf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE compcpoe  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE compclif  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE compreff  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE comptref  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE compsatf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE compmedf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE compbilf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE comppatf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE compprof  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE compoth   -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE educreqf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE caserevf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE committf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE outcome   -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE utilizaf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE satisfyf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE nocharge  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE feescale  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundmedf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundme0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundsmha  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundstaf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundst0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundst1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundlocf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundva    -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundcsbg  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundcmhg  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundclif  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundprvf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundothf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE fundot0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE majorsif  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE majorfuf  -9='(-9) MISSING' -6='(-6) MISSING' -2='(-2) Logical Skip'
                  -1='(-1) UNKNOWN' 1='(01) Medicaid' 2='(02) Medicare'
                  3='(03) State mental health agency funds'
                  4='(04) State welfare or child or family services agency funds'
                  5='(05) State corrections or juvenile justice agency funds'
                  6='(06) State education agency funds'
                  7='(07) Local government funds'
                  8='(08) U.S. Department of Veterans Affairs funds'
                  9='(09) Community Service Block Grants'
                  10='(10) Community Mental Health Block Grants'
                  11='(11) Client/patient fees' 12='(12) Private insurance'
                  13='(13) Other public funds' 14='(14) Other private funds' ;
  VALUE smokin0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  1='(1) Smoking not permitted on property or within building'
                  2='(2) Smoking is permitted only outdoors'
                  3='(3) Smoking permitted outdoors and in designated indoor areas'
                  4='(4) Smoking is permitted anywhere without restriction'
                  5='(5) Other' ;
  VALUE usedsecf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE adoptsef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licensef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licens0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licens1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licens2f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licens3f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licens4f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licens5f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licens6f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licens7f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licens8f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licens9f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licen10f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE faconly   -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  1='(1) Only this facility'
                  2='(2) This facility plus others'
                  3='(3) Another facility in organization will report client counts for this facility' ;
  VALUE totalfac  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipserv    -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE iptotal   -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipsextof  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipsexpef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipsext0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipsexp0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipagetof  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipagepef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipaget0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipagep0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipaget1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipagep1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipethtof  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipethpef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipetht0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipethp0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipetht1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipethp1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipracetf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipracepf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iprace0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iprace1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iprace2f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iprace3f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iprace4f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iprace5f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iprace6f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iprace7f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iprace8f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iprace9f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iprac10f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iprac11f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iplegalf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iplega0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iplega1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iplega2f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iplega3f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE iplega4f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE ipbeds    -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcserv    -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE rctotal   -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcsextof  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcsexpef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcsext0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcsexp0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcagetof  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcagepef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcaget0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcagep0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcaget1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcagep1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcethtof  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcethpef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcetht0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcethp0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcetht1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcethp1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcracetf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcracepf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcrace0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcrace1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcrace2f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcrace3f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcrace4f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcrace5f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcrace6f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcrace7f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcrace8f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcrace9f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcrac10f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcrac11f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rclegalf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rclega0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rclega1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rclega2f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rclega3f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rclega4f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE rcbeds    -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opserv    -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN'
                  0='(0) No' 1='(1) Yes' ;
  VALUE optotal   -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opsextof  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opsexpef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opsext0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opsexp0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opagetof  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opagepef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opaget0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opagep0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opaget1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opagep1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opethtof  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opethpef  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opetht0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opethp0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opetht1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opethp1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opracetf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE opracepf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oprace0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oprace1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oprace2f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oprace3f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oprace4f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oprace5f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oprace6f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oprace7f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oprace8f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oprace9f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oprac10f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oprac11f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oplegalf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oplega0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oplega1f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oplega2f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oplega3f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE oplega4f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE percentf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE mhadmisf  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE percen0f  -9='(-9) MISSING' -6='(-6) MISSING' -1='(-1) UNKNOWN' ;
  VALUE srvchar   0='(0) Not Reported' 1='(1) Reported' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=945;
INPUT
        CASEID 1-5              STFIPS 6-8              MODE 9-11
        MHINTAKE 12-14          MHDIAGEVAL 15-17        MHREFERRAL 18-20
        SASERV 21-23            MENTALHTHSERV 24-26     ADMINSERV 27-29
        SETTINGIP 30-32         SETTINGRC 33-35         SETTINGOP 36-38
        FACILITYTYPE 39-41      FOCUS 42-44             OWNERSHIP 45-47
        RELIGIOUS 48-50         TREATACTVTYTHRPY 51-53  TREATBEHAVMOD 54-56
        TREATCOGTHRPY 57-59     TREATFAMTHRPY 60-62     TREATELECTRO 63-65
        TREATGRPTHRPY 66-68     TREATPSYCHOTHRPY 69-71  TREATDUALMHSA 72-74
        TREATPSYCHOMED 75-77    TREATTELEMEDINCE 78-80  TREATOTH 81-83
        ASSERTCOMM 84-86        MHCASEMGMT 87-89        MHCHRONIC 90-92
        MHCONSUMER 93-95        MHEDUCATION 96-98       FAMPSYCHED 99-101
        MHHOUSING 102-104       ILLNESSMGMT 105-107     MHLEGAL 108-110
        MHEMGCY 111-113         MHPSYCHREHAB 114-116    SMOKINGCESSATION 117-119
        MHSUICIDE 120-122       SUPPEMPLOY 123-125      SUPPHOUSING 126-128
        FOSTERCARE 129-131      MHVOCREHAB 132-134      MHOTH 135-137
        CHILDADOL 138-140       ADULTS 141-143          SENIORS 144-146
        SED 147-149             TRANSITIONAGE 150-152   SPMI 153-155
        ALZHDEMENTIA 156-158    MHANDSA 159-161         MHANDOTHER 162-164
        POSTTRAUM 165-167       VETERNS 168-170         TRAUMATICBRAIN 171-173
        GLBT 174-176            FORENSIC 177-179        PROGOTH 180-182
        HEARIMPAIR 183-185      LANGENGLISH 186-188     LANGSPANISH 189-191
        LANGOTH 192-194         CRISISTEAM 195-197      COMPRESULTRPTG 198-200
        COMPCPOE 201-203        COMPCLINDATA 204-206    COMPREFERRALS 207-209
        COMPTREATPLAN 210-212   COMPSATISFYSURVEY 213-215 COMPMEDCHECK 216-218
        COMPBILLING 219-221     COMPPATIENTSCHED 222-224 COMPPROCESSNOTE 225-227
        COMPOTH 228-230         EDUCREQUIRE 231-233     CASEREVIEW 234-236
        COMMITTEE 237-239       OUTCOME 240-242         UTILIZATION 243-245
        SATISFYSURVEY 246-248   NOCHARGE 249-251        FEESCALE 252-254
        FUNDMEDICAID 255-257    FUNDMEDICARE 258-260    FUNDSMHA 261-263
        FUNDSTATEWELFARE 264-266 FUNDSTATEJUV 267-269    FUNDSTATEEDUC 270-272
        FUNDLOCALGOV 273-275    FUNDVA 276-278          FUNDCSBG 279-281
        FUNDCMHG 282-284        FUNDCLIENTFEES 285-287  FUNDPRVTINS 288-290
        FUNDOTHPUB 291-293      FUNDOTHPRVT 294-296     MAJORSINGLEFUND 297-299
        MAJORFUNDTYPE 300-302   SMOKINGPOLICY 303-305   USEDSECLUSION 306-308
        ADOPTSECLUSION 309-311  LICENSESMHA 312-314     LICENSESA 315-317
        LICENSEDPH 318-320      LICENSEHOSPLIC 321-323  LICENSEJC 324-326
        LICENSECARF 327-329     LICENSECOA 330-332      LICENSEDFCS 333-335
        LICENSEDHHS 336-338     LICENSEMEDICARE 339-341 LICENSEMEDICAID 342-344
        LICENSEOTHORG 345-347   FACONLY 348-350         TOTALFAC 351-353
        IPSERV 354-356          IPTOTAL 357-361         IPSEXTOTM 362-366
        IPSEXPERM 367-371       IPSEXTOTF 372-376       IPSEXPERF 377-381
        IPAGETOT017 382-386     IPAGEPER017 387-391     IPAGETOT1864 392-396
        IPAGEPER1864 397-401    IPAGETOT65 402-406      IPAGEPER65 407-411
        IPETHTOTHISP 412-416    IPETHPERHISP 417-421    IPETHTOTNONHISP 422-426
        IPETHPERNONHISP 427-431 IPETHTOTUNK 432-436     IPETHPERUNK 437-441
        IPRACETOTINDIAN 442-446 IPRACEPERINDIAN 447-451 IPRACETOTASIAN 452-456
        IPRACEPERASIAN 457-461  IPRACETOTBLK 462-466    IPRACEPERBLK 467-471
        IPRACETOTHAWPAC 472-476 IPRACEPERHAWPAC 477-481 IPRACETOTWHIT 482-486
        IPRACEPERWHIT 487-491   IPRACETOTMR 492-496     IPRACEPERMR 497-501
        IPRACETOTUNK 502-506    IPRACEPERUNK 507-511    IPLEGALTOTVOL 512-516
        IPLEGALPERVOL 517-521   IPLEGALTOTNONFOREN 522-526 IPLEGALPERNONFOREN 527-531
        IPLEGALTOTFOREN 532-536 IPLEGALPERFOREN 537-541 IPBEDS 542-546
        RCSERV 547-549          RCTOTAL 550-554         RCSEXTOTM 555-559
        RCSEXPERM 560-564       RCSEXTOTF 565-569       RCSEXPERF 570-574
        RCAGETOT017 575-579     RCAGEPER017 580-584     RCAGETOT1864 585-589
        RCAGEPER1864 590-594    RCAGETOT65 595-599      RCAGEPER65 600-604
        RCETHTOTHISP 605-609    RCETHPERHISP 610-614    RCETHTOTNONHISP 615-619
        RCETHPERNONHISP 620-624 RCETHTOTUNK 625-629     RCETHPERUNK 630-634
        RCRACETOTINDIAN 635-639 RCRACEPERINDIAN 640-644 RCRACETOTASIAN 645-649
        RCRACEPERASIAN 650-654  RCRACETOTBLK 655-659    RCRACEPERBLK 660-664
        RCRACETOTHAWPAC 665-669 RCRACEPERHAWPAC 670-674 RCRACETOTWHIT 675-679
        RCRACEPERWHIT 680-684   RCRACETOTMR 685-689     RCRACEPERMR 690-694
        RCRACETOTUNK 695-699    RCRACEPERUNK 700-704    RCLEGALTOTVOL 705-709
        RCLEGALPERVOL 710-714   RCLEGALTOTNONFOREN 715-719 RCLEGALPERNONFOREN 720-724
        RCLEGALTOTFOREN 725-729 RCLEGALPERFOREN 730-734 RCBEDS 735-739
        OPSERV 740-742          OPTOTAL 743-747         OPSEXTOTM 748-752
        OPSEXPERM 753-757       OPSEXTOTF 758-762       OPSEXPERF 763-767
        OPAGETOT017 768-772     OPAGEPER017 773-777     OPAGETOT1864 778-782
        OPAGEPER1864 783-787    OPAGETOT65 788-792      OPAGEPER65 793-797
        OPETHTOTHISP 798-802    OPETHPERHISP 803-807    OPETHTOTNONHISP 808-812
        OPETHPERNONHISP 813-817 OPETHTOTUNK 818-822     OPETHPERUNK 823-827
        OPRACETOTINDIAN 828-832 OPRACEPERINDIAN 833-837 OPRACETOTASIAN 838-842
        OPRACEPERASIAN 843-847  OPRACETOTBLK 848-852    OPRACEPERBLK 853-857
        OPRACETOTHAWPAC 858-862 OPRACEPERHAWPAC 863-867 OPRACETOTWHIT 868-872
        OPRACEPERWHIT 873-877   OPRACETOTMR 878-882     OPRACEPERMR 883-887
        OPRACETOTUNK 888-892    OPRACEPERUNK 893-897    OPLEGALTOTVOL 898-902
        OPLEGALPERVOL 903-907   OPLEGALTOTNONFOREN 908-912 OPLEGALPERNONFOREN 913-917
        OPLEGALTOTFOREN 918-922 OPLEGALPERFOREN 923-927 PERCENTCP 928-932
        MHADMISSIONS 933-937    PERCENTVA 938-942       SRVCHAR 943-945
        ;


* SAS LABEL STATEMENT;

LABEL 
   CASEID  = 'Case Identification Number' 
   STFIPS  = 'Census State FIPS codes label' 
   MODE    = 'Control: Completes by phone/mail/web' 
   MHINTAKE= 'QA1_1  Facility offers intake services' 
   MHDIAGEVAL= 'QA1_2  Facility offers diagnostic evaluation' 
   MHREFERRAL= 'QA1_3  Facility offers information and referral services' 
   SASERV  = 'QA1_4  Facility offers substance abuse treatment services' 
   MENTALHTHSERV= 'QA1_5  Facility offers mental health treatment services' 
   ADMINSERV= 'QA1_6  Facility offers administrative services' 
   SETTINGIP= 'QA3_1  Mental health treatment offered in hospital inpatient setting' 
   SETTINGRC= 'QA3_2  Mental health treatment offered in residential setting' 
   SETTINGOP= 'QA3_3  Mental health treatment offered in outpatient (or day treatment/partial hospitalization) 
setting' 
   FACILITYTYPE= 'QA5  Facility type' 
   FOCUS   = 'QA6  Primary treatment focus' 
   OWNERSHIP= 'QA7  Facility is operated by' 
   RELIGIOUS= 'QA8  Facility is affiliated with a religious organization' 
   TREATACTVTYTHRPY= 'QA10_1  Facility offers activity therapy' 
   TREATBEHAVMOD= 'QA10_2  Facility offers behavior modification' 
   TREATCOGTHRPY= 'QA10_3  Facility offers cognitive/behavioral therapy' 
   TREATFAMTHRPY= 'QA10_4  Facility offers couples/family therapy' 
   TREATELECTRO= 'QA10_5  Facility offers electroconvulsive therapy' 
   TREATGRPTHRPY= 'QA10_6  Facility offers group therapy' 
   TREATPSYCHOTHRPY= 'QA10_7  Facility offers individual psychotherapy' 
   TREATDUALMHSA= 'QA10_8  Facility offers integrated dual disorders treatment' 
   TREATPSYCHOMED= 'QA10_9  Facility offers psychotropic medication therapy' 
   TREATTELEMEDINCE= 'QA10_10  Facility offers telemedicine therapy' 
   TREATOTH= 'QA10_11  Facility offers other mental health treatment approaches' 
   ASSERTCOMM= 'QA11_1  Facility offers assertive community treatment' 
   MHCASEMGMT= 'QA11_2  Facility offers case management' 
   MHCHRONIC= 'QA11_3  Facility offers chronic disease/illness management' 
   MHCONSUMER= 'QA11_4  Facility offers consumer-run services' 
   MHEDUCATION= 'QA11_5  Facility offers education services' 
   FAMPSYCHED= 'QA11_6  Facility offers family psychoeducation' 
   MHHOUSING= 'QA11_7  Facility offers housing services' 
   ILLNESSMGMT= 'QA11_8  Facility offers illness management and recovery' 
   MHLEGAL = 'QA11_9  Facility offers legal advocacy services' 
   MHEMGCY = 'QA11_10  Facility offers psychiatric emergency walk-in services' 
   MHPSYCHREHAB= 'QA11_11  Facility offers psychosocial rehabilitation services' 
   SMOKINGCESSATION= 'QA11_12  Facility offers smoking cessation services' 
   MHSUICIDE= 'QA11_13  Facility offers suicide prevention services' 
   SUPPEMPLOY= 'QA11_14  Facility offers supported employment' 
   SUPPHOUSING= 'QA11_15  Facility offers supported housing' 
   FOSTERCARE= 'QA11_16  Facility offers therapeutic foster care' 
   MHVOCREHAB= 'QA11_17  Facility offers vocational rehabilitation services' 
   MHOTH   = 'QA11_18  Facility offers other supportive services' 
   CHILDADOL= 'QA12_1  Youth accepted at facility' 
   ADULTS  = 'QA12_2  Adults accepted at facility' 
   SENIORS = 'QA12_3  Seniors accepted at facility' 
   SED     = 'QA13_1  Offers program designed for youth with SED' 
   TRANSITIONAGE= 'QA13_2  Offers program designed for transition-aged young adults age 18-25' 
   SPMI    = 'QA13_3  Offers program designed for adults with SMI' 
   ALZHDEMENTIA= 'QA13_4  Offers program designed for individuals with Alzheimer''s or dementia' 
   MHANDSA = 'QA13_5  Offers program designed for co-occurring mental health and substance abuse disorders' 
   MHANDOTHER= 'QA13_6  Offers program designed for co-occurring mental health and non-sub- stance abuse disorders' 
   POSTTRAUM= 'QA13_7  Offers program designed for individuals with PTSD' 
   VETERNS = 'QA13_8  Offers program designed for veterans' 
   TRAUMATICBRAIN= 'QA13_9  Offers program designed for individuals with TBI' 
   GLBT    = 'QA13_10  Offers program designed for gay, lesbian, bisexual, or transgendered clients' 
   FORENSIC= 'QA13_11  Offers program designed for forensic clients' 
   PROGOTH = 'QA13_12  Offers other special program' 
   HEARIMPAIR= 'QA14  Offers mental health services for the hearing impaired' 
   LANGENGLISH= 'QA15_1  Provides mental health treatment services in English' 
   LANGSPANISH= 'QA15_2  Provides mental health treatment services in Spanish' 
   LANGOTH = 'QA15_3  Provides mental health treatment services in other language' 
   CRISISTEAM= 'QA16  Operates a crisis intervention team' 
   COMPRESULTRPTG= 'QA17_1  Uses computerized system for reporting results' 
   COMPCPOE= 'QA17_2   Uses computerized system for physician order entry of patient prescriptions or directions' 
   COMPCLINDATA= 'QA17_3  Uses computerized system for sending and receiving clinical data' 
   COMPREFERRALS= 'QA17_4  Uses computerized system for creating and transmitting referrals' 
   COMPTREATPLAN= 'QA17_5  Uses computerized system for creating and maintaining treatment plans' 
   COMPSATISFYSURVEY= 'QA17_6  Uses computerized system for client or family satisfaction surveys' 
   COMPMEDCHECK= 'QA17_7  Uses computerized system for checking medication interactions' 
   COMPBILLING= 'QA17_8  Uses computerized system for preparing and submitting bills or claims' 
   COMPPATIENTSCHED= 'QA17_9  Uses computerized system for scheduling clients/patients' 
   COMPPROCESSNOTE= 'QA17_10  Uses computerized system for process note-taking' 
   COMPOTH = 'QA17_11  Uses computerized system for other operational functions' 
   EDUCREQUIRE= 'QA18_1  Monitors continuing education requirements for staff' 
   CASEREVIEW= 'QA18_2  Regularly schedules case review with a supervisor' 
   COMMITTEE= 'QA18_3  Regularly schedules case review by a quality review committee' 
   OUTCOME = 'QA18_4  Client/patient outcome follow-up after discharge' 
   UTILIZATION= 'QA18_5  Periodic utilization review' 
   SATISFYSURVEY= 'QA18_6  Periodic client/patient satisfaction surveys' 
   NOCHARGE= 'QA19  Offers treatment at no charge to clients/patients' 
   FEESCALE= 'QA20  Uses sliding fee scale' 
   FUNDMEDICAID= 'QA21_1  Facility accepts Medicaid' 
   FUNDMEDICARE= 'QA21_2  Facility accepts Medicare' 
   FUNDSMHA= 'QA21_3  Facility accepts state mental health agency funds' 
   FUNDSTATEWELFARE= 'QA21_4  Facility accepts state welfare or child or family services agency funds' 
   FUNDSTATEJUV= 'QA21_5  Facility accepts state corrections or juvenile justice agency funds' 
   FUNDSTATEEDUC= 'QA21_6  Facility accepts state education agency funds' 
   FUNDLOCALGOV= 'QA21_7  Facility accepts local government funds' 
   FUNDVA  = 'QA21_8  Facility accepts (US Department of Veterans Affairs) VA funds' 
   FUNDCSBG= 'QA21_9  Facility accepts Community Service Block Grants' 
   FUNDCMHG= 'QA21_10  Facility accepts Community Mental Health Block Grants' 
   FUNDCLIENTFEES= 'QA21_11  Facility accepts client/patient fees' 
   FUNDPRVTINS= 'QA21_12  Facility accepts private insurance' 
   FUNDOTHPUB= 'QA21_13  Facility accepts other public funds' 
   FUNDOTHPRVT= 'QA21_14  Facility accepts other private funds' 
   MAJORSINGLEFUND= 'QA22  More than half of facility funds come from a single source' 
   MAJORFUNDTYPE= 'QA22a  The single source that funds more than half of the facility' 
   SMOKINGPOLICY= 'QA23  Facility smoking policy' 
   USEDSECLUSION= 'QA24_1  Staff have used seclusion or restraint practices in the past year' 
   ADOPTSECLUSION= 'QA24_2  Facility has adopted initiatives toward reduction of seclusion and restraint practices' 
   LICENSESMHA= 'QA25_1  Facility has licensing/certification/accreditation from state mental health agency' 
   LICENSESA= 'QA25_2  Facility has licensing/certification/accreditation from state substance abuse agency' 
   LICENSEDPH= 'QA25_3  Facility has licensing/certification/accreditation from state department of health' 
   LICENSEHOSPLIC= 'QA25_4  Facility has licensing/certification/accreditation from  hospital licensing authority' 
   LICENSEJC= 'QA25_5  Facility has licensing/certification/accreditation from JC (Joint Commission)' 
   LICENSECARF= 'QA25_6  Facility has licensing/certification/accreditation from CARF (Commission on Accreditation 
of Rehabilitation Facilities)' 
   LICENSECOA= 'QA25_7  Facility has licensing/certification/accreditation from COA (Council on Accreditation)' 
   LICENSEDFCS= 'QA25_8  Facility has licensing/certification/accreditation from Department of Family and Children 
Services' 
   LICENSEDHHS= 'QA25_9  Facility has licensing/certification/accreditation from US Dept of Health and Human Services' 
   LICENSEMEDICARE= 'QA25_10  Facility has licensing/certification/accreditation from Medicare' 
   LICENSEMEDICAID= 'QA25_11  Facility has licensing/certification/accreditation from Medicaid' 
   LICENSEOTHORG= 'QA25_12  Facility has licensing/certification/accreditation from other national/state/local 
organization' 
   FACONLY = 'QB1  Client/patient counts reported for only this facility/this facility plus others/another 
facility reporting client counts for this facility' 
   TOTALFAC= 'QB2_3  Total number of facilities included in reported client/patients counts' 
   IPSERV  = 'QB3  Patients received services in 24-hour hospital inpatient setting' 
   IPTOTAL = 'QB3a  Number of patients that received 24-hour hospital inpatient services' 
   IPSEXTOTM= 'QB3b_num_mal. Male hospital inpatients - Total' 
   IPSEXPERM= 'QB3b_per_mal. Male hospital inpatients - Percent' 
   IPSEXTOTF= 'QB3b_num_fem. Female hospital inpatients - Total' 
   IPSEXPERF= 'QB3b_per_fem. Female hospital inpatients - Percent' 
   IPAGETOT017= 'QB3b_num_age1. Ages 0-17 hospital inpatients - Total' 
   IPAGEPER017= 'QB3b_per_age1. Ages 0-17 hospital inpatients  - Percent' 
   IPAGETOT1864= 'QB3b_num_age2. Ages 18-64 hospital inpatients - Total' 
   IPAGEPER1864= 'QB3b_per_age2. Ages 18-64 hospital inpatients - Percent' 
   IPAGETOT65= 'QB3b_num_age3. Ages 65 plus hospital inpatients - Total' 
   IPAGEPER65= 'QB3b_per_age3. Ages 65 plus hospital inpatients - Percent' 
   IPETHTOTHISP= 'QB3b_num_his. Total Hispanic or Latino hospital inpatients' 
   IPETHPERHISP= 'QB3b_per_his. Percent Hispanic or Latino hospital inpatients' 
   IPETHTOTNONHISP= 'QB3b_num_nhis. Total non-Hispanic or Latino hospital inpatients' 
   IPETHPERNONHISP= 'QB3b_per_nhis. Percent non-Hispanic or Latino hospital inpatients' 
   IPETHTOTUNK= 'QB3_num_ethunk. Ethnicity unknown - Total hospital inpatients' 
   IPETHPERUNK= 'QB3_per_ethunk. Ethnicity unknown - Percent hospital inpatients' 
   IPRACETOTINDIAN= 'QB3b_num_nat. Total American Indian/Alaska Native hospital inpatients' 
   IPRACEPERINDIAN= 'QB3b_per_nat. Percent American Indian/Alaska Native hospital inpatients' 
   IPRACETOTASIAN= 'QB3b_num_asi. Total Asian hospital inpatients' 
   IPRACEPERASIAN= 'QB3b_per_asi. Percent Asian hospital inpatients' 
   IPRACETOTBLK= 'QB3b_num_bla. Total Black or African American hospital inpatients' 
   IPRACEPERBLK= 'QB3b_per_bla. Percent Black or African American hospital inpatients' 
   IPRACETOTHAWPAC= 'Q3b_num_haw. Total Native Hawaiian/Pacific Islander hospital inpatients' 
   IPRACEPERHAWPAC= 'Q3b_per_haw. Percent Native Hawaiian/Pacific Islander hospital inpatients' 
   IPRACETOTWHIT= 'QB3b_num_whi. Total White hospital inpatients' 
   IPRACEPERWHIT= 'QB3b_per_whi. Percent White hospital inpatients' 
   IPRACETOTMR= 'QB3b_num_mix. Two or more races - Total hospital inpatients' 
   IPRACEPERMR= 'QB3b_per_mix. Two or more races - Percent hospital inpatients' 
   IPRACETOTUNK= 'QB3b_num_raceunk. Race unknown or not collected - Total hospital inpatients' 
   IPRACEPERUNK= 'QB3_per_raceunk. Race unknown or not collected - Percent hospital inpatients' 
   IPLEGALTOTVOL= 'QB3b_num_vol. Voluntary legal status - Total hospital inpatients' 
   IPLEGALPERVOL= 'QB3b_per_vol. Voluntary legal status - Percent hospital inpatients' 
   IPLEGALTOTNONFOREN= 'QB3b_num_inn. Involuntary (non-forensic) legal status - Total hospital inpatients' 
   IPLEGALPERNONFOREN= 'QB3b_per_inn. Involuntary (non-forensic) legal status - Percent hospital inpatients' 
   IPLEGALTOTFOREN= 'QB3b_num_inf. Involuntary (forensic) legal status - Total hospital inpatients' 
   IPLEGALPERFOREN= 'QB3b_per_inf. Involuntary (forensic) legal status - Percent hospital inpatients' 
   IPBEDS  = 'QB3c  Number of hospital inpatient beds specifically designated for mental health' 
   RCSERV  = 'QB4  Clients received services in 24-hour residential care setting' 
   RCTOTAL = 'QB4a  Number of clients that received 24-hour residential care services' 
   RCSEXTOTM= 'QB4b_num_mal. Male residential care clients - Total' 
   RCSEXPERM= 'QB4b_per_mal. Male residential care clients - Percent' 
   RCSEXTOTF= 'QB4b_num_fem. Female residential care clients - Total' 
   RCSEXPERF= 'QB4b_per_fem. Female residential care clients - Percent' 
   RCAGETOT017= 'QB4b_num_age1. Ages 0-17 residential care clients - Total' 
   RCAGEPER017= 'QB4b_per_age1. Ages 0-17 residential care clients - Percent' 
   RCAGETOT1864= 'QB4b_num_age2. Ages 18-64 residential care clients - Total' 
   RCAGEPER1864= 'QB4b_per_age2. Ages 18-64 residential care clients - Percent' 
   RCAGETOT65= 'QB4b_num_age3. Ages 65 plus residential care clients - Total' 
   RCAGEPER65= 'QB4b_per_age3. Ages 65 plus residential care clients - Percent' 
   RCETHTOTHISP= 'QB4b_num_his. Total Hispanic or Latino residential care clients' 
   RCETHPERHISP= 'QB4b_per_his. Percent Hispanic or Latino residential care clients' 
   RCETHTOTNONHISP= 'QB4b_num_nhis. Total non-Hispanic or Latino residential care clients' 
   RCETHPERNONHISP= 'QB4b_per_nhis. Percent non-Hispanic or Latino residential care clients' 
   RCETHTOTUNK= 'QB4_num_ethunk. Ethnicity unknown - Total residential care clients' 
   RCETHPERUNK= 'QB4_per_ethunk. Ethnicity unknown - Percent residential care clients' 
   RCRACETOTINDIAN= 'QB4b_num_nat. Total American Indian/Alaska Native residential care clients' 
   RCRACEPERINDIAN= 'QB4b_per_nat. Percent American Indian/Alaska Native residential care clients' 
   RCRACETOTASIAN= 'QB4b_num_asi. Total Asian residential care clients' 
   RCRACEPERASIAN= 'QB4b_per_asi. Percent Asian residential care clients' 
   RCRACETOTBLK= 'QB4b_num_bla. Total Black or African American residential care clients' 
   RCRACEPERBLK= 'QB4b_per_bla. Percent Black or African American residential care clients' 
   RCRACETOTHAWPAC= 'QB4b_num_haw. Total Native Hawaiian/Pacific islander residential care clients' 
   RCRACEPERHAWPAC= 'QB4b_per_haw. Percentage Native Hawaiian/Pacific Islander residential care clients' 
   RCRACETOTWHIT= 'QB4b_num_whi. Total White residential care clients' 
   RCRACEPERWHIT= 'QB4b_per_whi. Percent White residential care clients' 
   RCRACETOTMR= 'QB4b_num_mix. Two or more races - Total residential care clients' 
   RCRACEPERMR= 'QB4b_per_mix. Two or more races - Percent residential care clients' 
   RCRACETOTUNK= 'QB4b_num_raceunk. Race unknown or not collected - Total residential care clients' 
   RCRACEPERUNK= 'QB4_per_raceunk. Race unknown or not collected - Percent residential care clients' 
   RCLEGALTOTVOL= 'QB4b_num_vol. Voluntary legal status - Total residential care clients' 
   RCLEGALPERVOL= 'QB4b_per_vol. Voluntary legal status - Percent residential care clients' 
   RCLEGALTOTNONFOREN= 'QB4b_num_inn. Involuntary (non-forensic) legal status - Total residential care clients' 
   RCLEGALPERNONFOREN= 'QB4b_per_inn. Involuntary (non-forensic) legal status - Percent residential care clients' 
   RCLEGALTOTFOREN= 'QB4b_num_inf. Involuntary (forensic) legal status - Total residential care clients' 
   RCLEGALPERFOREN= 'QB4b_per_inf. Involuntary (forensic) legal status - Percent residential care clients' 
   RCBEDS  = 'QB4c  Number of residential beds specifically designated for mental health' 
   OPSERV  = 'QB5  Clients received services in an outpatient setting' 
   OPTOTAL = 'QB5a  Number of clients that received outpatient (or day treatment/partial hospitalization) services' 
   OPSEXTOTM= 'QB5b_num_mal. Male outpatients - Total' 
   OPSEXPERM= 'QB5b_per_mal. Male outpatients - Percent' 
   OPSEXTOTF= 'QB5b_num_fem. Female outpatients - Total' 
   OPSEXPERF= 'QB5b_per_fem. Female outpatients - Percent' 
   OPAGETOT017= 'QB5b_num_age1. Ages 0-17 outpatients - Total' 
   OPAGEPER017= 'QB5b_per_age1. Ages 0-17 outpatients - Percent' 
   OPAGETOT1864= 'QB5b_num_age2. Ages 18-64 outpatients - Total' 
   OPAGEPER1864= 'QB5b_per_age2. Ages 18-64 outpatients - Percent' 
   OPAGETOT65= 'QB5b_num_age3. Ages 65 plus outpatients - Total' 
   OPAGEPER65= 'QB5b_per_age3. Ages 65 plus outpatients - Percent' 
   OPETHTOTHISP= 'QB5b_num_his. Total Hispanic or Latino outpatients' 
   OPETHPERHISP= 'QB5b_per_his. Percent Hispanic or Latino outpatients' 
   OPETHTOTNONHISP= 'QB5b_num_nhis. Total non-Hispanic or Latino outpatients' 
   OPETHPERNONHISP= 'QB5b_per_nhis. Percent non-Hispanic or Latino outpatients' 
   OPETHTOTUNK= 'QB5_num_ethunk. Ethnicity unknown - Total outpatients' 
   OPETHPERUNK= 'QB5_per_ethunk. Ethnicity unknown - Percent outpatients' 
   OPRACETOTINDIAN= 'QB5b_num_nat. Total American Indian/Alaska Native outpatients' 
   OPRACEPERINDIAN= 'QB5b_per_nat. Percent American Indian/Alaska Native outpatients' 
   OPRACETOTASIAN= 'QB5b_num_asi. Total Asian outpatients' 
   OPRACEPERASIAN= 'QB5b_per_asi. Percent Asian outpatients' 
   OPRACETOTBLK= 'QB5b_num_bla. Total Black or African American outpatients' 
   OPRACEPERBLK= 'QB5b_per_bla. Percent Black or African American outpatients' 
   OPRACETOTHAWPAC= 'QB5b_num_haw. Total Native Hawaiian/Pacific Islander outpatients' 
   OPRACEPERHAWPAC= 'QB5b_per_haw. Percent Native Hawaiian/Pacific Islander outpatients' 
   OPRACETOTWHIT= 'QB5b_num_whi. Total White outpatients' 
   OPRACEPERWHIT= 'QB5b_per_whi. Percent White outpatients' 
   OPRACETOTMR= 'QB5b_num_mix. Two or more races - Total outpatients' 
   OPRACEPERMR= 'QB5b_per_mix. Two or more races - Percent outpatients' 
   OPRACETOTUNK= 'QB5b_num_raceunk. Unknown race or not collected - Total outpatients' 
   OPRACEPERUNK= 'QB5_per_raceunk. Unknown race or not collected - Percent outpatients' 
   OPLEGALTOTVOL= 'QB5b_num_vol. Voluntary legal status - Total outpatients' 
   OPLEGALPERVOL= 'QB5b_per_vol. Voluntary legal status - Percent outpatients' 
   OPLEGALTOTNONFOREN= 'QB5b_num_inn. Involuntary (non-forensic) legal status - Total outpatients' 
   OPLEGALPERNONFOREN= 'QB5b_per_inn. Involuntary (non-forensic) legal status - Percent outpatients' 
   OPLEGALTOTFOREN= 'QB5b_num_inf. Involuntary (forensic) legal status - Total outpatients' 
   OPLEGALPERFOREN= 'QB5b_per_inf. Involuntary (forensic) legal status - Percent outpatients' 
   PERCENTCP= 'QB6  Percent of client/patients diagnosed with co-occurring mental health and substance abuse 
disorders' 
   MHADMISSIONS= 'QB7  Number of mental health admissions in 12 month period' 
   PERCENTVA= 'QB8  Percent of admissions who were military veterans' 
   SRVCHAR = 'Services characteristics(Reported=1, Not reported=0)' 
        ; 


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (MHINTAKE <= -1) THEN MHINTAKE = .;
   IF (MHDIAGEVAL <= -1) THEN MHDIAGEVAL = .;
   IF (MHREFERRAL <= -1) THEN MHREFERRAL = .;
   IF (SASERV <= -1) THEN SASERV = .;
   IF (MENTALHTHSERV <= -1) THEN MENTALHTHSERV = .;
   IF (ADMINSERV <= -1) THEN ADMINSERV = .;
   IF (SETTINGIP <= -1) THEN SETTINGIP = .;
   IF (SETTINGRC <= -1) THEN SETTINGRC = .;
   IF (SETTINGOP <= -1) THEN SETTINGOP = .;
   IF (FACILITYTYPE <= -1) THEN FACILITYTYPE = .;
   IF (FOCUS <= -1) THEN FOCUS = .;
   IF (OWNERSHIP <= -1) THEN OWNERSHIP = .;
   IF (RELIGIOUS <= -1) THEN RELIGIOUS = .;
   IF (TREATACTVTYTHRPY <= -1) THEN TREATACTVTYTHRPY = .;
   IF (TREATBEHAVMOD <= -1) THEN TREATBEHAVMOD = .;
   IF (TREATCOGTHRPY <= -1) THEN TREATCOGTHRPY = .;
   IF (TREATFAMTHRPY <= -1) THEN TREATFAMTHRPY = .;
   IF (TREATELECTRO <= -1) THEN TREATELECTRO = .;
   IF (TREATGRPTHRPY <= -1) THEN TREATGRPTHRPY = .;
   IF (TREATPSYCHOTHRPY <= -1) THEN TREATPSYCHOTHRPY = .;
   IF (TREATDUALMHSA <= -1) THEN TREATDUALMHSA = .;
   IF (TREATPSYCHOMED <= -1) THEN TREATPSYCHOMED = .;
   IF (TREATTELEMEDINCE <= -1) THEN TREATTELEMEDINCE = .;
   IF (TREATOTH <= -1) THEN TREATOTH = .;
   IF (ASSERTCOMM <= -1) THEN ASSERTCOMM = .;
   IF (MHCASEMGMT <= -1) THEN MHCASEMGMT = .;
   IF (MHCHRONIC <= -1) THEN MHCHRONIC = .;
   IF (MHCONSUMER <= -1) THEN MHCONSUMER = .;
   IF (MHEDUCATION <= -1) THEN MHEDUCATION = .;
   IF (FAMPSYCHED <= -1) THEN FAMPSYCHED = .;
   IF (MHHOUSING <= -1) THEN MHHOUSING = .;
   IF (ILLNESSMGMT <= -1) THEN ILLNESSMGMT = .;
   IF (MHLEGAL <= -1) THEN MHLEGAL = .;
   IF (MHEMGCY <= -1) THEN MHEMGCY = .;
   IF (MHPSYCHREHAB <= -1) THEN MHPSYCHREHAB = .;
   IF (SMOKINGCESSATION <= -1) THEN SMOKINGCESSATION = .;
   IF (MHSUICIDE <= -1) THEN MHSUICIDE = .;
   IF (SUPPEMPLOY <= -1) THEN SUPPEMPLOY = .;
   IF (SUPPHOUSING <= -1) THEN SUPPHOUSING = .;
   IF (FOSTERCARE <= -1) THEN FOSTERCARE = .;
   IF (MHVOCREHAB <= -1) THEN MHVOCREHAB = .;
   IF (MHOTH <= -1) THEN MHOTH = .;
   IF (CHILDADOL <= -1) THEN CHILDADOL = .;
   IF (ADULTS <= -1) THEN ADULTS = .;
   IF (SENIORS <= -1) THEN SENIORS = .;
   IF (SED <= -1) THEN SED = .;
   IF (TRANSITIONAGE <= -1) THEN TRANSITIONAGE = .;
   IF (SPMI <= -1) THEN SPMI = .;
   IF (ALZHDEMENTIA <= -1) THEN ALZHDEMENTIA = .;
   IF (MHANDSA <= -1) THEN MHANDSA = .;
   IF (MHANDOTHER <= -1) THEN MHANDOTHER = .;
   IF (POSTTRAUM <= -1) THEN POSTTRAUM = .;
   IF (VETERNS <= -1) THEN VETERNS = .;
   IF (TRAUMATICBRAIN <= -1) THEN TRAUMATICBRAIN = .;
   IF (GLBT <= -1) THEN GLBT = .;
   IF (FORENSIC <= -1) THEN FORENSIC = .;
   IF (PROGOTH <= -1) THEN PROGOTH = .;
   IF (HEARIMPAIR <= -1) THEN HEARIMPAIR = .;
   IF (LANGENGLISH <= -1) THEN LANGENGLISH = .;
   IF (LANGSPANISH <= -1) THEN LANGSPANISH = .;
   IF (LANGOTH <= -1) THEN LANGOTH = .;
   IF (CRISISTEAM <= -1) THEN CRISISTEAM = .;
   IF (COMPRESULTRPTG <= -1) THEN COMPRESULTRPTG = .;
   IF (COMPCPOE <= -1) THEN COMPCPOE = .;
   IF (COMPCLINDATA <= -1) THEN COMPCLINDATA = .;
   IF (COMPREFERRALS <= -1) THEN COMPREFERRALS = .;
   IF (COMPTREATPLAN <= -1) THEN COMPTREATPLAN = .;
   IF (COMPSATISFYSURVEY <= -1) THEN COMPSATISFYSURVEY = .;
   IF (COMPMEDCHECK <= -1) THEN COMPMEDCHECK = .;
   IF (COMPBILLING <= -1) THEN COMPBILLING = .;
   IF (COMPPATIENTSCHED <= -1) THEN COMPPATIENTSCHED = .;
   IF (COMPPROCESSNOTE <= -1) THEN COMPPROCESSNOTE = .;
   IF (COMPOTH <= -1) THEN COMPOTH = .;
   IF (EDUCREQUIRE <= -1) THEN EDUCREQUIRE = .;
   IF (CASEREVIEW <= -1) THEN CASEREVIEW = .;
   IF (COMMITTEE <= -1) THEN COMMITTEE = .;
   IF (OUTCOME <= -1) THEN OUTCOME = .;
   IF (UTILIZATION <= -1) THEN UTILIZATION = .;
   IF (SATISFYSURVEY <= -1) THEN SATISFYSURVEY = .;
   IF (NOCHARGE <= -1) THEN NOCHARGE = .;
   IF (FEESCALE <= -1) THEN FEESCALE = .;
   IF (FUNDMEDICAID <= -1) THEN FUNDMEDICAID = .;
   IF (FUNDMEDICARE <= -1) THEN FUNDMEDICARE = .;
   IF (FUNDSMHA <= -1) THEN FUNDSMHA = .;
   IF (FUNDSTATEWELFARE <= -1) THEN FUNDSTATEWELFARE = .;
   IF (FUNDSTATEJUV <= -1) THEN FUNDSTATEJUV = .;
   IF (FUNDSTATEEDUC <= -1) THEN FUNDSTATEEDUC = .;
   IF (FUNDLOCALGOV <= -1) THEN FUNDLOCALGOV = .;
   IF (FUNDVA <= -1) THEN FUNDVA = .;
   IF (FUNDCSBG <= -1) THEN FUNDCSBG = .;
   IF (FUNDCMHG <= -1) THEN FUNDCMHG = .;
   IF (FUNDCLIENTFEES <= -1) THEN FUNDCLIENTFEES = .;
   IF (FUNDPRVTINS <= -1) THEN FUNDPRVTINS = .;
   IF (FUNDOTHPUB <= -1) THEN FUNDOTHPUB = .;
   IF (FUNDOTHPRVT <= -1) THEN FUNDOTHPRVT = .;
   IF (MAJORSINGLEFUND <= -1) THEN MAJORSINGLEFUND = .;
   IF (MAJORFUNDTYPE <= -1) THEN MAJORFUNDTYPE = .;
   IF (SMOKINGPOLICY <= -1) THEN SMOKINGPOLICY = .;
   IF (USEDSECLUSION <= -1) THEN USEDSECLUSION = .;
   IF (ADOPTSECLUSION <= -1) THEN ADOPTSECLUSION = .;
   IF (LICENSESMHA <= -1) THEN LICENSESMHA = .;
   IF (LICENSESA <= -1) THEN LICENSESA = .;
   IF (LICENSEDPH <= -1) THEN LICENSEDPH = .;
   IF (LICENSEHOSPLIC <= -1) THEN LICENSEHOSPLIC = .;
   IF (LICENSEJC <= -1) THEN LICENSEJC = .;
   IF (LICENSECARF <= -1) THEN LICENSECARF = .;
   IF (LICENSECOA <= -1) THEN LICENSECOA = .;
   IF (LICENSEDFCS <= -1) THEN LICENSEDFCS = .;
   IF (LICENSEDHHS <= -1) THEN LICENSEDHHS = .;
   IF (LICENSEMEDICARE <= -1) THEN LICENSEMEDICARE = .;
   IF (LICENSEMEDICAID <= -1) THEN LICENSEMEDICAID = .;
   IF (LICENSEOTHORG <= -1) THEN LICENSEOTHORG = .;
   IF (FACONLY <= -1) THEN FACONLY = .;
   IF (TOTALFAC <= -1) THEN TOTALFAC = .;
   IF (IPSERV <= -1) THEN IPSERV = .;
   IF (IPTOTAL <= -1) THEN IPTOTAL = .;
   IF (IPSEXTOTM <= -1) THEN IPSEXTOTM = .;
   IF (IPSEXPERM <= -1) THEN IPSEXPERM = .;
   IF (IPSEXTOTF <= -1) THEN IPSEXTOTF = .;
   IF (IPSEXPERF <= -1) THEN IPSEXPERF = .;
   IF (IPAGETOT017 <= -1) THEN IPAGETOT017 = .;
   IF (IPAGEPER017 <= -1) THEN IPAGEPER017 = .;
   IF (IPAGETOT1864 <= -1) THEN IPAGETOT1864 = .;
   IF (IPAGEPER1864 <= -1) THEN IPAGEPER1864 = .;
   IF (IPAGETOT65 <= -1) THEN IPAGETOT65 = .;
   IF (IPAGEPER65 <= -1) THEN IPAGEPER65 = .;
   IF (IPETHTOTHISP <= -1) THEN IPETHTOTHISP = .;
   IF (IPETHPERHISP <= -1) THEN IPETHPERHISP = .;
   IF (IPETHTOTNONHISP <= -1) THEN IPETHTOTNONHISP = .;
   IF (IPETHPERNONHISP <= -1) THEN IPETHPERNONHISP = .;
   IF (IPETHTOTUNK <= -1) THEN IPETHTOTUNK = .;
   IF (IPETHPERUNK <= -1) THEN IPETHPERUNK = .;
   IF (IPRACETOTINDIAN <= -1) THEN IPRACETOTINDIAN = .;
   IF (IPRACEPERINDIAN <= -1) THEN IPRACEPERINDIAN = .;
   IF (IPRACETOTASIAN <= -1) THEN IPRACETOTASIAN = .;
   IF (IPRACEPERASIAN <= -1) THEN IPRACEPERASIAN = .;
   IF (IPRACETOTBLK <= -1) THEN IPRACETOTBLK = .;
   IF (IPRACEPERBLK <= -1) THEN IPRACEPERBLK = .;
   IF (IPRACETOTHAWPAC <= -1) THEN IPRACETOTHAWPAC = .;
   IF (IPRACEPERHAWPAC <= -1) THEN IPRACEPERHAWPAC = .;
   IF (IPRACETOTWHIT <= -1) THEN IPRACETOTWHIT = .;
   IF (IPRACEPERWHIT <= -1) THEN IPRACEPERWHIT = .;
   IF (IPRACETOTMR <= -1) THEN IPRACETOTMR = .;
   IF (IPRACEPERMR <= -1) THEN IPRACEPERMR = .;
   IF (IPRACETOTUNK <= -1) THEN IPRACETOTUNK = .;
   IF (IPRACEPERUNK <= -1) THEN IPRACEPERUNK = .;
   IF (IPLEGALTOTVOL <= -1) THEN IPLEGALTOTVOL = .;
   IF (IPLEGALPERVOL <= -1) THEN IPLEGALPERVOL = .;
   IF (IPLEGALTOTNONFOREN <= -1) THEN IPLEGALTOTNONFOREN = .;
   IF (IPLEGALPERNONFOREN <= -1) THEN IPLEGALPERNONFOREN = .;
   IF (IPLEGALTOTFOREN <= -1) THEN IPLEGALTOTFOREN = .;
   IF (IPLEGALPERFOREN <= -1) THEN IPLEGALPERFOREN = .;
   IF (IPBEDS <= -1) THEN IPBEDS = .;
   IF (RCSERV <= -1) THEN RCSERV = .;
   IF (RCTOTAL <= -1) THEN RCTOTAL = .;
   IF (RCSEXTOTM <= -1) THEN RCSEXTOTM = .;
   IF (RCSEXPERM <= -1) THEN RCSEXPERM = .;
   IF (RCSEXTOTF <= -1) THEN RCSEXTOTF = .;
   IF (RCSEXPERF <= -1) THEN RCSEXPERF = .;
   IF (RCAGETOT017 <= -1) THEN RCAGETOT017 = .;
   IF (RCAGEPER017 <= -1) THEN RCAGEPER017 = .;
   IF (RCAGETOT1864 <= -1) THEN RCAGETOT1864 = .;
   IF (RCAGEPER1864 <= -1) THEN RCAGEPER1864 = .;
   IF (RCAGETOT65 <= -1) THEN RCAGETOT65 = .;
   IF (RCAGEPER65 <= -1) THEN RCAGEPER65 = .;
   IF (RCETHTOTHISP <= -1) THEN RCETHTOTHISP = .;
   IF (RCETHPERHISP <= -1) THEN RCETHPERHISP = .;
   IF (RCETHTOTNONHISP <= -1) THEN RCETHTOTNONHISP = .;
   IF (RCETHPERNONHISP <= -1) THEN RCETHPERNONHISP = .;
   IF (RCETHTOTUNK <= -1) THEN RCETHTOTUNK = .;
   IF (RCETHPERUNK <= -1) THEN RCETHPERUNK = .;
   IF (RCRACETOTINDIAN <= -1) THEN RCRACETOTINDIAN = .;
   IF (RCRACEPERINDIAN <= -1) THEN RCRACEPERINDIAN = .;
   IF (RCRACETOTASIAN <= -1) THEN RCRACETOTASIAN = .;
   IF (RCRACEPERASIAN <= -1) THEN RCRACEPERASIAN = .;
   IF (RCRACETOTBLK <= -1) THEN RCRACETOTBLK = .;
   IF (RCRACEPERBLK <= -1) THEN RCRACEPERBLK = .;
   IF (RCRACETOTHAWPAC <= -1) THEN RCRACETOTHAWPAC = .;
   IF (RCRACEPERHAWPAC <= -1) THEN RCRACEPERHAWPAC = .;
   IF (RCRACETOTWHIT <= -1) THEN RCRACETOTWHIT = .;
   IF (RCRACEPERWHIT <= -1) THEN RCRACEPERWHIT = .;
   IF (RCRACETOTMR <= -1) THEN RCRACETOTMR = .;
   IF (RCRACEPERMR <= -1) THEN RCRACEPERMR = .;
   IF (RCRACETOTUNK <= -1) THEN RCRACETOTUNK = .;
   IF (RCRACEPERUNK <= -1) THEN RCRACEPERUNK = .;
   IF (RCLEGALTOTVOL <= -1) THEN RCLEGALTOTVOL = .;
   IF (RCLEGALPERVOL <= -1) THEN RCLEGALPERVOL = .;
   IF (RCLEGALTOTNONFOREN <= -1) THEN RCLEGALTOTNONFOREN = .;
   IF (RCLEGALPERNONFOREN <= -1) THEN RCLEGALPERNONFOREN = .;
   IF (RCLEGALTOTFOREN <= -1) THEN RCLEGALTOTFOREN = .;
   IF (RCLEGALPERFOREN <= -1) THEN RCLEGALPERFOREN = .;
   IF (RCBEDS <= -1) THEN RCBEDS = .;
   IF (OPSERV <= -1) THEN OPSERV = .;
   IF (OPTOTAL <= -1) THEN OPTOTAL = .;
   IF (OPSEXTOTM <= -1) THEN OPSEXTOTM = .;
   IF (OPSEXPERM <= -1) THEN OPSEXPERM = .;
   IF (OPSEXTOTF <= -1) THEN OPSEXTOTF = .;
   IF (OPSEXPERF <= -1) THEN OPSEXPERF = .;
   IF (OPAGETOT017 <= -1) THEN OPAGETOT017 = .;
   IF (OPAGEPER017 <= -1) THEN OPAGEPER017 = .;
   IF (OPAGETOT1864 <= -1) THEN OPAGETOT1864 = .;
   IF (OPAGEPER1864 <= -1) THEN OPAGEPER1864 = .;
   IF (OPAGETOT65 <= -1) THEN OPAGETOT65 = .;
   IF (OPAGEPER65 <= -1) THEN OPAGEPER65 = .;
   IF (OPETHTOTHISP <= -1) THEN OPETHTOTHISP = .;
   IF (OPETHPERHISP <= -1) THEN OPETHPERHISP = .;
   IF (OPETHTOTNONHISP <= -1) THEN OPETHTOTNONHISP = .;
   IF (OPETHPERNONHISP <= -1) THEN OPETHPERNONHISP = .;
   IF (OPETHTOTUNK <= -1) THEN OPETHTOTUNK = .;
   IF (OPETHPERUNK <= -1) THEN OPETHPERUNK = .;
   IF (OPRACETOTINDIAN <= -1) THEN OPRACETOTINDIAN = .;
   IF (OPRACEPERINDIAN <= -1) THEN OPRACEPERINDIAN = .;
   IF (OPRACETOTASIAN <= -1) THEN OPRACETOTASIAN = .;
   IF (OPRACEPERASIAN <= -1) THEN OPRACEPERASIAN = .;
   IF (OPRACETOTBLK <= -1) THEN OPRACETOTBLK = .;
   IF (OPRACEPERBLK <= -1) THEN OPRACEPERBLK = .;
   IF (OPRACETOTHAWPAC <= -1) THEN OPRACETOTHAWPAC = .;
   IF (OPRACEPERHAWPAC <= -1) THEN OPRACEPERHAWPAC = .;
   IF (OPRACETOTWHIT <= -1) THEN OPRACETOTWHIT = .;
   IF (OPRACEPERWHIT <= -1) THEN OPRACEPERWHIT = .;
   IF (OPRACETOTMR <= -1) THEN OPRACETOTMR = .;
   IF (OPRACEPERMR <= -1) THEN OPRACEPERMR = .;
   IF (OPRACETOTUNK <= -1) THEN OPRACETOTUNK = .;
   IF (OPRACEPERUNK <= -1) THEN OPRACEPERUNK = .;
   IF (OPLEGALTOTVOL <= -1) THEN OPLEGALTOTVOL = .;
   IF (OPLEGALPERVOL <= -1) THEN OPLEGALPERVOL = .;
   IF (OPLEGALTOTNONFOREN <= -1) THEN OPLEGALTOTNONFOREN = .;
   IF (OPLEGALPERNONFOREN <= -1) THEN OPLEGALPERNONFOREN = .;
   IF (OPLEGALTOTFOREN <= -1) THEN OPLEGALTOTFOREN = .;
   IF (OPLEGALPERFOREN <= -1) THEN OPLEGALPERFOREN = .;
   IF (PERCENTCP <= -1) THEN PERCENTCP = .;
   IF (MHADMISSIONS <= -1) THEN MHADMISSIONS = .;
   IF (PERCENTVA <= -1) THEN PERCENTVA = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT STFIPS stfips. MODE mode. MHINTAKE mhintake.
         MHDIAGEVAL mhdiagef. MHREFERRAL mhreferf. SASERV saserv.
         MENTALHTHSERV mentalhf. ADMINSERV adminsef. SETTINGIP settingf.
         SETTINGRC settin0f. SETTINGOP settin1f. FACILITYTYPE facilitf.
         FOCUS focus. OWNERSHIP ownershf. RELIGIOUS religiof.
         TREATACTVTYTHRPY treatacf. TREATBEHAVMOD treatbef. TREATCOGTHRPY treatcof.
         TREATFAMTHRPY treatfaf. TREATELECTRO treatelf. TREATGRPTHRPY treatgrf.
         TREATPSYCHOTHRPY treatpsf. TREATDUALMHSA treatduf. TREATPSYCHOMED treatp0f.
         TREATTELEMEDINCE treattef. TREATOTH treatoth. ASSERTCOMM assertcf.
         MHCASEMGMT mhcasemf. MHCHRONIC mhchronf. MHCONSUMER mhconsuf.
         MHEDUCATION mheducaf. FAMPSYCHED fampsycf. MHHOUSING mhhousif.
         ILLNESSMGMT illnessf. MHLEGAL mhlegal. MHEMGCY mhemgcy.
         MHPSYCHREHAB mhpsychf. SMOKINGCESSATION smokingf. MHSUICIDE mhsuicif.
         SUPPEMPLOY suppempf. SUPPHOUSING supphouf. FOSTERCARE fostercf.
         MHVOCREHAB mhvocref. MHOTH mhoth. CHILDADOL childadf.
         ADULTS adults. SENIORS seniors. SED sed.
         TRANSITIONAGE transitf. SPMI spmi. ALZHDEMENTIA alzhdemf.
         MHANDSA mhandsa. MHANDOTHER mhandotf. POSTTRAUM posttraf.
         VETERNS veterns. TRAUMATICBRAIN traumatf. GLBT glbt.
         FORENSIC forensic. PROGOTH progoth. HEARIMPAIR hearimpf.
         LANGENGLISH langengf. LANGSPANISH langspaf. LANGOTH langoth.
         CRISISTEAM crisistf. COMPRESULTRPTG compresf. COMPCPOE compcpoe.
         COMPCLINDATA compclif. COMPREFERRALS compreff. COMPTREATPLAN comptref.
         COMPSATISFYSURVEY compsatf. COMPMEDCHECK compmedf. COMPBILLING compbilf.
         COMPPATIENTSCHED comppatf. COMPPROCESSNOTE compprof. COMPOTH compoth.
         EDUCREQUIRE educreqf. CASEREVIEW caserevf. COMMITTEE committf.
         OUTCOME outcome. UTILIZATION utilizaf. SATISFYSURVEY satisfyf.
         NOCHARGE nocharge. FEESCALE feescale. FUNDMEDICAID fundmedf.
         FUNDMEDICARE fundme0f. FUNDSMHA fundsmha. FUNDSTATEWELFARE fundstaf.
         FUNDSTATEJUV fundst0f. FUNDSTATEEDUC fundst1f. FUNDLOCALGOV fundlocf.
         FUNDVA fundva. FUNDCSBG fundcsbg. FUNDCMHG fundcmhg.
         FUNDCLIENTFEES fundclif. FUNDPRVTINS fundprvf. FUNDOTHPUB fundothf.
         FUNDOTHPRVT fundot0f. MAJORSINGLEFUND majorsif. MAJORFUNDTYPE majorfuf.
         SMOKINGPOLICY smokin0f. USEDSECLUSION usedsecf. ADOPTSECLUSION adoptsef.
         LICENSESMHA licensef. LICENSESA licens0f. LICENSEDPH licens1f.
         LICENSEHOSPLIC licens2f. LICENSEJC licens3f. LICENSECARF licens4f.
         LICENSECOA licens5f. LICENSEDFCS licens6f. LICENSEDHHS licens7f.
         LICENSEMEDICARE licens8f. LICENSEMEDICAID licens9f. LICENSEOTHORG licen10f.
         FACONLY faconly. TOTALFAC totalfac. IPSERV ipserv.
         IPTOTAL iptotal. IPSEXTOTM ipsextof. IPSEXPERM ipsexpef.
         IPSEXTOTF ipsext0f. IPSEXPERF ipsexp0f. IPAGETOT017 ipagetof.
         IPAGEPER017 ipagepef. IPAGETOT1864 ipaget0f. IPAGEPER1864 ipagep0f.
         IPAGETOT65 ipaget1f. IPAGEPER65 ipagep1f. IPETHTOTHISP ipethtof.
         IPETHPERHISP ipethpef. IPETHTOTNONHISP ipetht0f. IPETHPERNONHISP ipethp0f.
         IPETHTOTUNK ipetht1f. IPETHPERUNK ipethp1f. IPRACETOTINDIAN ipracetf.
         IPRACEPERINDIAN ipracepf. IPRACETOTASIAN iprace0f. IPRACEPERASIAN iprace1f.
         IPRACETOTBLK iprace2f. IPRACEPERBLK iprace3f. IPRACETOTHAWPAC iprace4f.
         IPRACEPERHAWPAC iprace5f. IPRACETOTWHIT iprace6f. IPRACEPERWHIT iprace7f.
         IPRACETOTMR iprace8f. IPRACEPERMR iprace9f. IPRACETOTUNK iprac10f.
         IPRACEPERUNK iprac11f. IPLEGALTOTVOL iplegalf. IPLEGALPERVOL iplega0f.
         IPLEGALTOTNONFOREN iplega1f. IPLEGALPERNONFOREN iplega2f. IPLEGALTOTFOREN iplega3f.
         IPLEGALPERFOREN iplega4f. IPBEDS ipbeds. RCSERV rcserv.
         RCTOTAL rctotal. RCSEXTOTM rcsextof. RCSEXPERM rcsexpef.
         RCSEXTOTF rcsext0f. RCSEXPERF rcsexp0f. RCAGETOT017 rcagetof.
         RCAGEPER017 rcagepef. RCAGETOT1864 rcaget0f. RCAGEPER1864 rcagep0f.
         RCAGETOT65 rcaget1f. RCAGEPER65 rcagep1f. RCETHTOTHISP rcethtof.
         RCETHPERHISP rcethpef. RCETHTOTNONHISP rcetht0f. RCETHPERNONHISP rcethp0f.
         RCETHTOTUNK rcetht1f. RCETHPERUNK rcethp1f. RCRACETOTINDIAN rcracetf.
         RCRACEPERINDIAN rcracepf. RCRACETOTASIAN rcrace0f. RCRACEPERASIAN rcrace1f.
         RCRACETOTBLK rcrace2f. RCRACEPERBLK rcrace3f. RCRACETOTHAWPAC rcrace4f.
         RCRACEPERHAWPAC rcrace5f. RCRACETOTWHIT rcrace6f. RCRACEPERWHIT rcrace7f.
         RCRACETOTMR rcrace8f. RCRACEPERMR rcrace9f. RCRACETOTUNK rcrac10f.
         RCRACEPERUNK rcrac11f. RCLEGALTOTVOL rclegalf. RCLEGALPERVOL rclega0f.
         RCLEGALTOTNONFOREN rclega1f. RCLEGALPERNONFOREN rclega2f. RCLEGALTOTFOREN rclega3f.
         RCLEGALPERFOREN rclega4f. RCBEDS rcbeds. OPSERV opserv.
         OPTOTAL optotal. OPSEXTOTM opsextof. OPSEXPERM opsexpef.
         OPSEXTOTF opsext0f. OPSEXPERF opsexp0f. OPAGETOT017 opagetof.
         OPAGEPER017 opagepef. OPAGETOT1864 opaget0f. OPAGEPER1864 opagep0f.
         OPAGETOT65 opaget1f. OPAGEPER65 opagep1f. OPETHTOTHISP opethtof.
         OPETHPERHISP opethpef. OPETHTOTNONHISP opetht0f. OPETHPERNONHISP opethp0f.
         OPETHTOTUNK opetht1f. OPETHPERUNK opethp1f. OPRACETOTINDIAN opracetf.
         OPRACEPERINDIAN opracepf. OPRACETOTASIAN oprace0f. OPRACEPERASIAN oprace1f.
         OPRACETOTBLK oprace2f. OPRACEPERBLK oprace3f. OPRACETOTHAWPAC oprace4f.
         OPRACEPERHAWPAC oprace5f. OPRACETOTWHIT oprace6f. OPRACEPERWHIT oprace7f.
         OPRACETOTMR oprace8f. OPRACEPERMR oprace9f. OPRACETOTUNK oprac10f.
         OPRACEPERUNK oprac11f. OPLEGALTOTVOL oplegalf. OPLEGALPERVOL oplega0f.
         OPLEGALTOTNONFOREN oplega1f. OPLEGALPERNONFOREN oplega2f. OPLEGALTOTFOREN oplega3f.
         OPLEGALPERFOREN oplega4f. PERCENTCP percentf. MHADMISSIONS mhadmisf.
         PERCENTVA percen0f. SRVCHAR srvchar.  ;
*/

RUN ;
